@@ -192,17 +192,21 @@ class PageEditor(object):
         img = self.original_img
         for e in self.active_modifiers:
             img = e.transform(img, preview=False)
+        # XXX(Jflesch): First go back the doc view. Because when
+        # calling `page_get_img_url` or others, some plugins may do
+        # shady things (see paperwork_gtk.model.help._get_doc_url()
+        # for instance)
+        self.core.call_success(
+            "mainloop_schedule", self.ui.on_edit_end,
+            self.doc_url, self.page_idx
+        )
         page_url = self.core.call_success(
             "page_get_img_url", self.doc_url, self.page_idx, write=True
         )
         self.core.call_success("pillow_to_url", img, page_url)
         # Drop the text so the OCR will be run again
-        self.core.call_all(
-            "page_set_boxes_by_url", self.doc_url, self.page_idx, []
-        )
         self.core.call_success(
-            "mainloop_schedule", self.ui.on_edit_end,
-            self.doc_url, self.page_idx
+            "page_set_boxes_by_url", self.doc_url, self.page_idx, []
         )
 
     def on_save(self):
@@ -236,7 +240,7 @@ class Plugin(openpaperwork_core.PluginBase):
             {
                 'interface': 'pillow',
                 'defaults': [
-                    'paperwork_backend.pillow.img',
+                    'openpaperwork_core.pillow.img',
                     'paperwork_backend.pillow.pdf',
                 ]
             },
